##  Configuration
In the Automations section of the administration area, create a set of four automations. Automations 1 and 2 use the same script. You can create automation 2 by copying automation 1 and adjusting the trigger. For configuration details, see:
  * [Automation 1: Relation Is Added (Business Context to Child)](https://help.sap.com/docs/leanix/ea/propagating-business-context-relations-to-parent-applications-relation-inheritance?locale=en-US&state=PRODUCTION&version=CLOUD#loio2ad6775d50c442168a6dd398192dab72__automation-1)
  * [Automation 2: Relation Is Removed (Business Context from Child)](https://help.sap.com/docs/leanix/ea/propagating-business-context-relations-to-parent-applications-relation-inheritance?locale=en-US&state=PRODUCTION&version=CLOUD#loio2ad6775d50c442168a6dd398192dab72__automation-2)
  * [Automation 3: Child Unlinked from Parent (Parent Side)](https://help.sap.com/docs/leanix/ea/propagating-business-context-relations-to-parent-applications-relation-inheritance?locale=en-US&state=PRODUCTION&version=CLOUD#loio2ad6775d50c442168a6dd398192dab72__automation-3)
  * [Automation 4: Child Removes Parent Relation (Catch-All)](https://help.sap.com/docs/leanix/ea/propagating-business-context-relations-to-parent-applications-relation-inheritance?locale=en-US&state=PRODUCTION&version=CLOUD#loio2ad6775d50c442168a6dd398192dab72__automation-4)


**Note**
In scripts, replace placeholder URLs with your values. To learn how to find your base URL, see [Base URL](https://help.sap.com/docs/leanix/ea/base-url?locale=en-US&state=PRODUCTION&version=CLOUD "Learn about the SAP LeanIX base URL and how to get your subdomain value.").
